@@ -7,6 +7,7 @@ from random import randint
 from dataclasses_json import DataClassJsonMixin
 
 
+
 class JobType(str, Enum):
   TEXT_2_IMAGE = "text2image"
   IMAGE_2_IMAGE = "image2image"
@@ -92,12 +93,17 @@ class Job(DataClassJsonMixin):
 
 @dataclass
 class FilterExample(DataClassJsonMixin):
+  # primary key is filter_id + tags
   image_data: ImageData 
   filter_id: typing.Optional[str]=None
   source_image_data: typing.Optional[ImageData ]=None
   strength: float = 1.0
   tags: list[str]= field(default_factory=list)
   example_group: typing.Optional[str]=None # deprecated
+
+  def id(self):
+    assert self.filter_id is not None
+    return f"{self.filter_id}_{'_'.join(self.tags)}"
   
 @dataclass
 class Filter(DataClassJsonMixin):
@@ -112,8 +118,13 @@ class Filter(DataClassJsonMixin):
   is_premium: bool = False
   user_secret_id: typing.Optional[str] = None
   creation_time: datetime = datetime.utcnow()
-  thumbnail_uri: typing.Optional[str] = None #deprecated
   examples: typing.Optional[list[FilterExample]] = None
+  
+  text_compatible: bool = False
+  face_specific: bool = False
+  human_specific: bool = False
+
+  thumbnail_uri: typing.Optional[str] = None #deprecated
 
 @dataclass
 class AppFilters(DataClassJsonMixin):
